pub struct InputCaptureChannel<'d, T: GeneralInstance4Channel> { /* private fields */ }Expand description
A single channel of an input capture-configured timer, obtained from
InputCapture::split, InputCapture::channel, InputCapture::ch1, etc.
Implementations
Sourceimpl<'d, T: GeneralInstance4Channel> InputCaptureChannel<'d, T>
impl<'d, T: GeneralInstance4Channel> InputCaptureChannel<'d, T>
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check whether this channel is enabled.
Sourcepub fn set_input_capture_mode(&mut self, mode: InputCaptureMode)
pub fn set_input_capture_mode(&mut self, mode: InputCaptureMode)
Set the input capture mode for this channel.
Sourcepub fn set_input_ti_selection(&mut self, tisel: InputTISelection)
pub fn set_input_ti_selection(&mut self, tisel: InputTISelection)
Set input TI selection for this channel.
Sourcepub fn set_input_capture_filter(&mut self, filter: FilterValue)
pub fn set_input_capture_filter(&mut self, filter: FilterValue)
Set the input capture filter for this channel.
Sourcepub fn set_input_capture_prescaler(&mut self, factor: u8)
pub fn set_input_capture_prescaler(&mut self, factor: u8)
Set the input capture prescaler for this channel.
Sourcepub fn get_capture_value(&self) -> T::Word
pub fn get_capture_value(&self) -> T::Word
Get capture value for this channel.
Sourcepub fn get_input_interrupt(&self) -> bool
pub fn get_input_interrupt(&self) -> bool
Get input interrupt for this channel.
Sourcepub async fn wait_for_rising_edge(&mut self) -> T::Word
pub async fn wait_for_rising_edge(&mut self) -> T::Word
Asynchronously wait until the pin sees a rising edge.
Sourcepub async fn wait_for_falling_edge(&mut self) -> T::Word
pub async fn wait_for_falling_edge(&mut self) -> T::Word
Asynchronously wait until the pin sees a falling edge.
Sourcepub async fn wait_for_any_edge(&mut self) -> T::Word
pub async fn wait_for_any_edge(&mut self) -> T::Word
Asynchronously wait until the pin sees any edge.
Sourcepub async fn wait_for_rising_edge_alternate(&mut self) -> T::Word
pub async fn wait_for_rising_edge_alternate(&mut self) -> T::Word
Asynchronously wait until the (alternate) pin sees a rising edge.
Sourcepub async fn wait_for_falling_edge_alternate(&mut self) -> T::Word
pub async fn wait_for_falling_edge_alternate(&mut self) -> T::Word
Asynchronously wait until the (alternate) pin sees a falling edge.
Sourcepub async fn wait_for_any_edge_alternate(&mut self) -> T::Word
pub async fn wait_for_any_edge_alternate(&mut self) -> T::Word
Asynchronously wait until the (alternate) pin sees any edge.